﻿@Imports System.Web.WebPages.Scope
@Imports UserVoiceApi

@* FeedbackTab
  Summary:
    This method renders an UserVoice feedback tab widget in the current page
    
  Parameters in order of appearance:

    showTab: boolean(true (default)/false)
        Specifies if the tab has to be rendered in the current page or not
    
    alignment: string ("left" (Default), "right")
        Specifies the alignment of the tab in the current page

    backgroundcolor: RGB hex  (#f00 default value)
        Specifies the background color of the widget

    textColor: String ("white" (default),"blank")
        Specifies the text color of the widget
    
    hoverColor: RGB hex  (#06C default value)
        Specifies the background color of the widget

    language: Locale ("en" default value)
        Specifies the ISO code language of the widget within the given list of supported languages:
        cn, da, de, en, es, fi, fr, he, it, ja, nl, no_NB, pl, pt, pt_BR, tr

    ssoToken:
        Specifies the token for the single sign on 

    forum: String
        Specifies a forum Id for the widget
*@
@Helper FeedbackTab(Optional ByVal showTab As Boolean = True,
                    Optional ByVal alignment As String = "left",
                    Optional ByVal backgroundColor As String = "#f00",
                    Optional ByVal textColor As String = "white",
                    Optional ByVal hoverColor As String = "#06C",
                    Optional ByVal language As String = "en",
                    Optional ByVal ssoToken As String = Nothing,
                    Optional ByVal forum As String = "")        
                        
                        Dim forumId = If(forum.Equals(String.Empty), _Forum, forum)
                        If IsInitialized Then
    @<script type="text/javascript">
            var uservoiceOptions = {
                
            /* required */
            key: '@Key',
            host:'@Host', 
            forum: '@forumId',
            showTab: @showTab.ToString().ToLower(),  
                
            /* optional */
            alignment: '@alignment',
            background_color: '@backgroundColor', 
            text_color: '@textColor',
            hover_color: '@hoverColor',
            lang: '@language',
            params: { sso: '@ssoToken' }
            };
                
            function _loadUserVoice() {
            var s = document.createElement('script');
            s.setAttribute('type', 'text/javascript');
            s.setAttribute('src', ("https:" == document.location.protocol ? "https://" : "http://") + "cdn.uservoice.com/javascripts/widgets/tab.js");
            document.getElementsByTagName('head')[0].appendChild(s);
            }
            _loadSuper = window.onload;
            window.onload = (typeof window.onload != 'function') ? _loadUserVoice : function() { _loadSuper(); _loadUserVoice(); };
    </script>
                        Else
    @<div>
        User Voice Helper is not initialized. Please call UserVoice.Initialize(credential
        params) in your _AppStart.cshtml page passing in your website credentials for UserVoice
    </div>
                        End If
End Helper
@* CustomTab
Summary:
        This method renders an UserVoice custom tab widget

Parameters:
  
    alignment: string ("left" (Default), "right")
        Specifies the alignment of the tab in the current page

    backgroundcolor: RGB hex  (#f00 default value)
        Specifies the background color of the widget

    textColor: String ("white" (default),"blank")
        Specifies the text color of the widget
    
    hoverColor: RGB hex  (#06C default value)
        Specifies the background color of the widget

    language: Locale ("en" default value)
        Specifies the ISO code language of the widget within the given list of supported languages:
                        cn, da, de, en, es, fi, fr, he, it, ja, nl, no_NB, pl, pt, pt_BR, tr
          
    forum: String
        Specifies a forum Id for the widget
*@
@Helper CustomTab(Optional ByVal alignment As String = "left",
                Optional ByVal backgroundColor As String = "#f00",
                Optional ByVal textColor As String = "white",
                Optional ByVal hoverColor As String = "#06C",
                Optional ByVal language As String = "en",
                Optional ByVal forum As String = "")
    @FeedbackTab(False, alignment, backgroundColor, textColor, hoverColor, language, Nothing, forum)   	    

End Helper
@*
FeedbackTabWithSSO
Summary:
    This method renders an UserVoice FeedbackTab using Single Sign On

Parameters (for the tab):
    showTab: boolean(true (default)/false)
        Specifies if the tab has to be rendered in the current page or not
    
    alignment: string ("left" (Default), "right")
        Specifies the alignment of the tab in the current page

    backgroundcolor: RGB hex  (#f00 default value)
        Specifies the background color of the widget

    textColor: String ("white" (default),"blank")
        Specifies the text color of the widget
    
    hoverColor: RGB hex  (#06C default value)
        Specifies the background color of the widget

    language: Locale ("en" default value)
        Specifies the ISO code language of the widget within the given list of supported languages:
        cn, da, de, en, es, fi, fr, he, it, ja, nl, no_NB, pl, pt, pt_BR, tr   

Parameters (for Single Sign On):
    displayName: String ("anonymous" defautl value)
        Specifies the user name to be displayed

    admin: String ("deny" default value, "accept")
        Grant the user account admin access. 

    avatarUrl: String
        Specifies the user avatar url, restricted to 50px by 50px size

    email: String
        Specifies user's email address

    expires: Timestamp, GMT
        Specifies the token expiration time

    guid: String
        Specifies user unique identifies

    url: String
        Sets all user profile links to this URL

    allowForums: Array
        Specifies the exclusive list of Forum ids user has access to (doesn't restrict admins)

    denyForums: Array
        Specifies the list of Forum ids user does not have access to (doesn't restrict admins)

    updates: Boolean ("false" default, "true")
     	Specifies whether the user will receive updates on suggestions (on create only) 
    
    commentUpdates: Boolean ("false" default, "true")
        Specifies whether the user will receive updates on suggestion comments (on create only) 

    owner: String ("accept")
        Make this user the account owner

    locale: String
        Specifies the ISO code language of the current user within the given list of supported languages:
        cn, da, de, en, es, fi, fr, he, it, ja, nl, no_NB, pl, pt, pt_BR, tr  

    forum: String
        Specifies a forum Id for the widget
*@
@Helper FeedbackTabWithSSO(Optional ByVal showTab As Boolean = True,
                            Optional ByVal alignment As String = "left",
                            Optional ByVal backgroundColor As String = "#f00",
                            Optional ByVal textColor As String = "white",
                            Optional ByVal hoverColor As String = "#06C",
                            Optional ByVal language As String = "en",
                            Optional ByVal displayName As String = "",
                            Optional ByVal admin As String = "deny",
                            Optional ByVal avatarUrl As String = "",
                            Optional ByVal email As String = "",
                            Optional ByVal expires As String = "",
                            Optional ByVal guid As String = "",
                            Optional ByVal url As String = "",
                            Optional ByVal allowForums As String = "",
                            Optional ByVal denyForums As String = "",
                            Optional ByVal updates As String = "false",
                            Optional ByVal commentUpdates As String = "false",
                            Optional ByVal owner As String = "",
                            Optional ByVal locale As String = "",
                            Optional ByVal forum As String = "")

                                Dim forumId As String = If(_Forum.Equals(String.Empty), forum, _Forum)

                                If (Not SSOKey.IsEmpty()) AndAlso
                                    (Not guid.IsEmpty()) AndAlso
                                    (Not expires.IsEmpty()) Then
                                    
                                    Dim userDetails = New UserDetails With
                                                      {.DisplayName = displayName,
                                                          .Admin = admin,
                                                          .AvatarUrl = avatarUrl,
                                                          .Email = email,
                                                          .Expires = expires,
                                                          .Guid = guid, .Url = url,
                                                          .AllowForums = allowForums,
                                                          .DenyForums = denyForums,
                                                          .Updates = updates,
                                                          .CommentUpdates = commentUpdates,
                                                          .Owner = owner, .Locale = locale}

                                    Dim userJson = SSO.CreateUserJson(userDetails)
                                    Dim ssoToken = SSO.CreateToken(Key, ApiKey, userJson)

    @FeedbackTab(showTab, alignment, backgroundColor, textColor, hoverColor, language, ssoToken, forumId)
                                Else
    @<div>
        User Voice Helper is not initialized, or some required SSO data is missing. Please
        call UserVoice.Initialize(credential params) in your _AppStart.cshtml page passing
        in your website credentials for UserVoice, and provide the required Guid and Expiration
        values for SSO functionality.
    </div>
                                End If

End Helper
@Functions
    Private Shared ReadOnly _isInitializedKey As New Object
    Private Shared ReadOnly _userVoiceKey As New Object
    Private Shared ReadOnly _hostKey As New Object
    Private Shared ReadOnly _forumKey As New Object
    Private Shared ReadOnly _ssoKey As New Object
    Private Shared ReadOnly _apiKey As New Object

    ''' <summary>
    ''' GetForums method returns all the forums of the application
    ''' </summary>    
    ''' <returns>IList of dynamic</returns>    
    Public Shared Function GetForumList() As IList(Of Object)
        Dim forums = Api.GetForumList(Key, ApiKey)

        Return forums
    End Function

    ''' <summary>
    ''' GetForum retrieves the specified forum
    ''' </summary>    
    ''' <param name="forumId">Specifies the forum Id. By default, it uses the initialized value</param>
    ''' <returns>dynamic </returns> 
    Public Shared Function GetForum(Optional ByVal forumId As String = "") As Object
        Dim forum = Api.GetForum(If(forumId.IsEmpty(), _Forum, forumId), Key, ApiKey)

        Return forum
    End Function

    ''' <summary>
    ''' This method retrieves the list of suggestions from a forum using Json
    ''' </summary>    
    ''' <param name="forumId">Specifies the forum Id. By default, it uses the initialized value</param>
    ''' <returns>IList of dynamic</returns>    
    Public Shared Function GetSuggestions(Optional ByVal forumId As String = "") As IList(Of Object)
        Dim suggestions = Api.GetSuggestionsList(If(forumId.IsEmpty(), _Forum, forumId), Key, ApiKey)

        Return suggestions
    End Function

    ''' <summary>
    ''' This method retrieves the list of suggestions from a forum filtered by a search query using Json
    ''' </summary>    
    ''' <param name="forumId">Specifies the forum Id. By default, it uses the initialized value</param>
    ''' <param name="query">Specifies the search criteria</param>
    ''' <returns>IList of dynamic</returns>    
    Public Shared Function SearchForSuggestions(Optional ByVal forumId As String = "",
                                                Optional ByVal query As String = "") As IList(Of Object)
        Dim suggestions = Api.GetSuggestionsSearch(If(forumId.IsEmpty(), _Forum, forumId), query, Key, ApiKey)

        Return suggestions
    End Function

    ''' <summary>
    ''' This method retrieves the list of suggestions from a forum filtered by a search query using Json
    ''' </summary>    
    ''' <param name="forumId">Specifies the forum Id. By default, it uses the initialized value</param>
    ''' <param name="query">Specifies the search criteria</param>
    ''' <returns>IList of dynamic</returns>    
    Public Shared Function GetCommentsForSuggestion(Optional ByVal suggestionId As String = "",
                                                    Optional ByVal forumId As String = "",
                                                    Optional ByVal query As String = "") As IList(Of Object)
        Dim comments = Api.GetCommentsForSuggestions(suggestionId,
                                                     If(forumId.IsEmpty(), _Forum, forumId),
                                                    Key,
                                                    ApiKey)

        Return comments
    End Function

    ''' <summary>
    ''' Initialization property. Returns if the instance is initialized within the current scopestorage
    ''' </summary>
    Public Shared Property IsInitialized As Boolean
        Get
            Return CBool(If(ScopeStorage.CurrentScope(_isInitializedKey), False))
        End Get
        Private Set(ByVal value As Boolean)
            ScopeStorage.CurrentScope(_isInitializedKey) = value
        End Set
    End Property

    ''' <summary>
    ''' Initializes the helper with UserVoice parameters
    ''' </summary>
    ''' <param name="key">Specifies UserVoice key</param>
    ''' <param name="host">Specifies UserVoice host address</param>
    ''' <param name="forum">Optional. Specifies UserVoice forum</param>
    ''' <param name="ssoKey">Optional. Specifies UserVoice key for single sign on</param>
    ''' <param name="apiKey">Optional. Specifies Uservoice api key for api functionality</param>
    Public Shared Sub Initialize(ByVal key As String,
                                 ByVal host As String,
                                 Optional ByVal forum As String = "",
                                 Optional ByVal ssoKey As String = Nothing,
                                 Optional ByVal apiKey As String = Nothing)
        key = key
        host = host
        _Forum = forum
        ssoKey = ssoKey
        apiKey = apiKey

        If (Not key.IsEmpty()) AndAlso (Not host.IsEmpty()) Then
            IsInitialized = True
        End If
    End Sub

    Private Shared Property Key As String
        Get
            Return CStr(If(ScopeStorage.CurrentScope(_userVoiceKey), ""))
        End Get
        Set(ByVal value As String)
            ScopeStorage.CurrentScope(_userVoiceKey) = value
        End Set
    End Property

    Private Shared Property Host As String
        Get
            Return CStr(If(ScopeStorage.CurrentScope(_hostKey), ""))
        End Get
        Set(ByVal value As String)
            ScopeStorage.CurrentScope(_hostKey) = value
        End Set
    End Property

    Private Shared Property _Forum As String
        Get
            Return CStr(If(ScopeStorage.CurrentScope(_forumKey), ""))
        End Get
        Set(ByVal value As String)
            ScopeStorage.CurrentScope(_forumKey) = value
        End Set
    End Property

    Private Shared Property SSOKey As String
        Get
            Return CStr(If(ScopeStorage.CurrentScope(_ssoKey), ""))
        End Get
        Set(ByVal value As String)
            ScopeStorage.CurrentScope(_ssoKey) = value
        End Set
    End Property

    Private Shared Property ApiKey As String
        Get
            Return CStr(If(ScopeStorage.CurrentScope(_apiKey), ""))
        End Get
        Set(ByVal value As String)
            ScopeStorage.CurrentScope(_apiKey) = value
        End Set
    End Property
End Functions