﻿Imports System.IO
Imports System.Net
Imports System.Web.Helpers
Imports System.Web.Mvc
Imports System.Web.WebPages
Imports PhotoGallery.Repositories
Imports WebMatrix.WebData

Namespace PhotoGallery.Controllers
    Public Class GalleryController
        Inherits Controller
        Public Function [Default]() As ActionResult
            ViewBag.Title = "Photo Gallery"

            Dim db = New PhotoGalleryRepository()
            Dim galleries = db.GetGalleryList()

            Return View(galleries)
        End Function

        <Authorize()>
        Public Function [New]() As ActionResult
            ViewBag.Title = "New Gallery"

            Return View()
        End Function

        <HttpPost(), Authorize()>
        Public Function [New](ByVal Name As String) As ActionResult
            If Name.IsEmpty() Then
                ModelState.AddModelError("Name", "You must specify a gallery name.")
            End If

            If ModelState.IsValid Then
                Dim db = New PhotoGalleryRepository()
                Dim nameExists = db.GetGalleryCount(Name) > 0

                If nameExists Then
                    ModelState.AddModelError("Name", "A gallery with the supplied name already exists.")
                Else
                    Dim galleryId As Integer = db.CreateGallery(Name)
                    Return RedirectToAction("View", New With {Key .id = galleryId})
                End If
            End If

            Return View()
        End Function

        <OutputCache(Duration:=60)>
        Public Function Thumbnail(ByVal id As Integer) As ActionResult
            Dim db = New PhotoGalleryRepository()

            Dim gallery = db.GetGallery(id)
            If gallery Is Nothing Then
                Return HttpNotFound()
            End If

            Dim photos = db.GetTopPhotosForGallery(id)
            If photos.Count = 0 Then
                Return File(Server.MapPath("~/Content/Images/gallery-empty.png"), "image/jpeg")
            End If

            Using generator = New MultiThumbnailGenerator()
                For Each photo In photos
                    Using imageStream = New MemoryStream(CType(photo.FileContents, Byte()))
                        Using image = System.Drawing.Image.FromStream(imageStream)
                            generator.AddImage(image)
                        End Using
                    End Using
                Next photo
                Using outStream = New MemoryStream()
                    generator.WritePngToStream(outStream)
                    Dim image = New WebImage(outStream)
                    image.Write()

                    Return Nothing
                End Using
            End Using
        End Function

        Public Function _View(ByVal id As Integer) As ActionResult
            Dim db = New PhotoGalleryRepository()

            Dim gallery = db.GetGallery(id)
            If gallery Is Nothing Then
                Return HttpNotFound()
            End If

            Dim photos = db.GetPhotosForGallery(id)

            ViewBag.Title = "Gallery - " & gallery.Name.ToString
            ViewBag.Name = gallery.Name
            ViewBag.GalleryId = id

            Return View(photos)
        End Function

        Public Function Upload(ByVal id As Integer) As ActionResult
            WebSecurity.RequireAuthenticatedUser()

            Dim db = New PhotoGalleryRepository()
            Dim gallery = db.GetGallery(id)

            If gallery Is Nothing Then
                Return HttpNotFound()
            End If

            ViewBag.Title = "Upload Photo to Gallery - " & gallery.Name.ToString

            Return View(gallery)
        End Function

        <HttpPost()>
        Public Function Upload() As ActionResult
            Dim db = New PhotoGalleryRepository()

            Dim id = Request.Url.Segments(3).AsInt()
            Dim numFiles = Request.Files.Count
            Dim imageId = 0

            For i = 0 To numFiles - 1
                Dim file = Request.Files(i)
                If file.ContentLength > 0 Then
                    Dim fileUpload = New WebImage(file.InputStream)
                    Dim fileTitle = Path.GetFileNameWithoutExtension(file.FileName).Trim()
                    If fileTitle.IsEmpty() Then
                        fileTitle = "Untitled"
                    End If
                    Dim fileExtension = Path.GetExtension(file.FileName).Trim()
                    Dim fileBytes = fileUpload.GetBytes()

                    imageId = db.InsertImage(id,
                                             WebSecurity.CurrentUserId,
                                             fileTitle, fileExtension,
                                             fileUpload.ImageFormat,
                                             fileBytes.Length,
                                             fileBytes)
                End If
            Next i

            Return RedirectToAction("View", "Photo", New With {Key .id = imageId})
        End Function
    End Class
End Namespace
