﻿Imports System.Dynamic
Imports System.Web.Helpers
Imports System.Web.Mvc
Imports System.Web.WebPages
Imports PhotoGallery.Repositories
Imports WebMatrix.WebData

Namespace after.Controllers
    Public Class PhotoController
        Inherits Controller
        Public Function _View(ByVal id? As Integer) As ActionResult
            If Not id.HasValue Then
                Return RedirectToRoute("Default")
            End If

            Dim photoDB = New PhotoGalleryRepository()
            Dim tagDB = New TagRepository()
            Dim userDB = New UserRepository()

            Dim photo = photoDB.GetPhoto(id.Value)
            If photo Is Nothing Then
                Return HttpNotFound()
            End If
            ViewBag.Title = "Photo - " & photo.FileTitle.ToString()

            Dim model As Object = New ExpandoObject()
            model.Photo = photo
            model.User = userDB.GetUserById(CType(photo.UserId, Integer))
            model.Gallery = photoDB.GetGallery(CType(photo.GalleryId, Integer))
            model.Comments = photoDB.GetCommentsByPhoto(CType(photo.Id, Integer))
            model.TagList = tagDB.GetTagListByPhoto(CType(photo.Id, Integer))

            Return View(model)
        End Function

        <HttpPost()>
        Public Function _View(ByVal id? As Integer, ByVal newComment As String) As ActionResult
            If Not id.HasValue Then
                Return RedirectToRoute("Default")
            End If

            If newComment.IsEmpty() Then
                Return RedirectToAction("View", New With {Key .id = id.Value})
            End If

            Dim db = New PhotoGalleryRepository()
            db.InsertComment(id.Value, newComment, WebSecurity.CurrentUserId)

            Return RedirectToAction("View", New With {Key .id = id.Value})
        End Function

        <OutputCache(Duration:=60)>
        Public Function Thumbnail(ByVal id As Integer) As ActionResult
            Dim db = New PhotoGalleryRepository()
            Dim photo = db.GetPhoto(id)

            If photo Is Nothing Then
                Return HttpNotFound()
            End If

            Dim size = If(Request("size"), "")

            Dim width As Integer
            Dim height As Integer
            Select Case size.ToUpperInvariant()
                Case "", "SMALL"
                    width = 200
                    height = 200
                Case "MEDIUM"
                    width = 400
                    height = 300
                Case "LARGE"
                    width = 625
                    height = 625
                Case Else
                    Return New HttpStatusCodeResult(400)
            End Select

            Dim image = New WebImage(photo.FileContents.ToString)
            image.Resize(width, height).Write()

            Return Nothing
        End Function

        <OutputCache(Duration:=60)>
        Public Function Full(ByVal id? As Integer) As ActionResult
            If Not id.HasValue Then
                Return RedirectToAction("View", New With {Key .id = id.Value})
            End If

            Dim db = New PhotoGalleryRepository()
            Dim photo = db.GetPhoto(id.Value)
            If photo Is Nothing Then
                Return HttpNotFound()
            End If

            Response.AppendHeader("Content-Disposition",
                                  String.Format("attachment; filename={0}", HttpUtility.UrlPathEncode(photo.FileTitle.ToString & photo.FileExtension.ToString)))
            CType(New WebImage(CType(photo.FileContents, Byte())), WebImage).Write()
            Return Nothing
        End Function
    End Class
End Namespace
