Imports WebMatrix.Data

Namespace PhotoGallery.Repositories
    Public Class PhotoGalleryRepository
        Private ReadOnly _database As Database
        Public Sub New()
            _database = Database.Open("PhotoGallery")
        End Sub

        Public Function GetGalleryList() As IList(Of Object)
            Return _database.Query("SELECT Galleries.Id, Galleries.Name, COUNT(Photos.Id) AS PhotoCount" & ControlChars.CrLf &
                                   "FROM Galleries LEFT OUTER JOIN Photos ON Galleries.Id = Photos.GalleryId" & ControlChars.CrLf &
                                   "GROUP BY Galleries.Id, Galleries.Name").ToList()
        End Function

        Public Function GetGalleryCount(ByVal galleryName As String) As Integer
            Return CType(_database.QueryValue("SELECT COUNT(*) FROM Galleries WHERE LOWER(Name) = LOWER(@0)", galleryName), Integer)
        End Function

        Public Function CreateGallery(ByVal galleryName As String) As Integer
            _database.Execute("INSERT INTO Galleries (Name) VALUES (@0)", galleryName)

            Return CInt(Fix(_database.GetLastInsertId()))
        End Function

        Public Function GetGallery(ByVal galleryId As Integer) As Object
            Return _database.QuerySingle("SELECT * FROM Galleries WHERE Id = @0", galleryId)
        End Function

        Public Function GetTopPhotosForGallery(ByVal galleryId As Integer) As IList(Of Object)
            Return _database.Query("SELECT TOP(3) FileContents, UploadDate FROM Photos WHERE GalleryId = @0 ORDER BY UploadDate DESC", galleryId).ToList()
        End Function

        Public Function GetPhotosForGallery(ByVal galleryId As Integer) As IList(Of Object)
            Return _database.Query("SELECT Id, FileTitle FROM Photos WHERE GalleryId = @0", galleryId).ToList()
        End Function

        Public Function InsertImage(ByVal galleryId As Integer,
                                    ByVal userId As Integer,
                                    ByVal fileTitle As String,
                                    ByVal fileExtension As String,
                                    ByVal imageFormat As String,
                                    ByVal length As Integer,
                                    ByVal image() As Byte) As Integer
            _database.Execute("INSERT INTO Photos" & ControlChars.CrLf &
                              "(GalleryId, UserId, Description, FileTitle, FileExtension, " & ControlChars.CrLf &
                              "ContentType, FileSize, UploadDate, FileContents) VALUES " & ControlChars.CrLf &
                              "(@0, @1, @2, @3, @4, @5, @6, @7, @8)",
                              galleryId, userId, "", fileTitle, fileExtension,
                              imageFormat, length, Date.Now, image)

            Return CInt(Fix(_database.GetLastInsertId()))
        End Function

        Public Function GetPhoto(ByVal photoId As Integer) As Object
            Return _database.QuerySingle("SELECT * FROM Photos WHERE Id = @0", photoId)
        End Function

        Public Sub InsertComment(ByVal id As Integer, ByVal newComment As String, ByVal userId As Integer)
            _database.Execute("INSERT INTO Comments (PhotoId, CommentDate, UserId, CommentText) " & ControlChars.CrLf &
                              "VALUES (@0, @1, @2, @3)", id, Date.Now, userId, newComment)
        End Sub

        Public Function GetCommentsByPhoto(ByVal id As Integer) As IList(Of Object)
            Return _database.Query("SELECT * FROM Comments INNER JOIN UserProfiles" & ControlChars.CrLf &
                                   "ON Comments.UserId = UserProfiles.UserId WHERE PhotoId = @0 " & ControlChars.CrLf &
                                   "ORDER BY Comments.CommentDate", id).ToList()
        End Function
    End Class
End Namespace