﻿@Imports WebMatrix.WebData
<div class="sidebar">
	<h1>@Model.Photo.FileTitle</h1>
	@If (Model.User.UserId = WebSecurity.CurrentUserId) Then
		@<p>
			As the author, you can <a href="@Url.Action("Edit", New With {.id = Model.Photo.Id})">edit</a>
			or <a href="@Url.Action("Remove", New With {.id = Model.Photo.Id})">remove</a> this photo.
		</p>
	End If 
	<dl>
		<dt class="description">Description</dt>
		<dd class="description">
			@If (Not String.IsNullOrEmpty(Model.Photo.Description)) Then
				@<text>@Model.Photo.Description</text>
			    Else
				@<text>The uploader did not provide a description for this photo.</text>
			End If 
		</dd>
		<dt class="uploaded-by">Uploaded by</dt>
		<dd class="uploaded-by"><a href="@Url.Action("View", New With {.id = Model.User.UserId})">@Model.User.DisplayName</a></dd>
		<dt class="upload-date">Upload date</dt>
		<dd class="upload-date">@Model.Photo.UploadDate</dd>
		<dt class="part-of-gallery">Gallery</dt>
		<dd><a href="@Url.Action("View", New With {.id = Model.Gallery.Id})" title="View @Model.Gallery.Name gallery">@Model.Gallery.Name</a></dd>
		<dt class="tags">Tags</dt>
		<dd class="tags">
			<ul class="tags">
			@If (Model.TagList.Count = 0) Then
				@<li>This photo has no tags.</li>
			    Else
			For Each t In Model.TagList
					@<li class="tag"><a href="@Url.Action("View", "Tag", New With {.tagName = t.Tags_TagName})">@t.Tags_TagName</a></li>
			Next
			 End If 
			</ul>
			@If (WebSecurity.IsAuthenticated) Then
				@<a href="@Url.Action("EditTags", New With {.id = Model.Photo.Id})">edit tags</a>
			End If 
		</dd>
	</dl>

	<p>
		<a class="download" href="@Url.Action("Full", New With {.id = Model.Photo.Id})" title="Download: @(Model.Photo.FileTitle + Model.Photo.FileExtension)">Download full photo</a> (@(Model.Photo.FileSize / 1024) KB)
	</p>
</div>
<div class="main">
	<img class="large-photo" alt="@Html.AttributeEncode(Model.Photo.FileTitle)" src="@Url.Action("Thumbnail", New With {.id = Model.Photo.Id, .size = "large"})" />

	@switch ((int)Model.Comments.Count) {
		case 0:
			<h2>Nobody has commented on this photo</h2>
			break;
		case 1:
			<h2>This photo has generated one comment.</h2>
			break;
		default:
			<h2>This photo has generated @Model.Comments.Count comments.</h2>
			break;
	}

	<ol class="comments">
		@For Each comment In Model.Comments
			@<li>
				<h3 class="comment-header">
					<a href="@Url.Action("View", "User", New With {.id = comment.UserId})" title="View @(comment.DisplayName)'s profile">@comment.DisplayName</a> commented at @comment.CommentDate:
				</h3>
				<p class="comment-body">@comment.CommentText</p>
			</li>
		next
	</ol>

	@If (WebSecurity.IsAuthenticated) Then
		@<form method="post" action="">
			<fieldset id="addComment">
				<legend>Post new comment</legend>
				<ol>
					<li>
						<label for="newComment">Comment</label>
						<textarea id="newComment" name="newComment" title="Your comment" rows="6" cols="70"></textarea>
					</li>
				</ol>
				<p class="form-actions">
					<input type="submit" title="Add comment" value="Add comment" />
				</p>
			</fieldset>
		</form>
	    Else
		@<p>
			Only registered user may leave comments. Please <a href="@Url.Action("Login", "Account")">login</a> 
			or <a href="@Url.Action("Register", "Account")">create an account</a> to leave a comment.
		</p>
	End If 
</div>