@Functions
    Public Enum DataCount
        Vertical
        Horizontal
        None
    End Enum
    
    Public Enum Languages
        English
        French
        German
        Spanish
        Japanese
    End Enum
    
    Public Shared Function GetLanguageCode(ByVal language As Languages) As String
        Select Case language
            Case Languages.French
                Return "fr"
            Case Languages.German
                Return "de"
            Case Languages.Spanish
                Return "es"
            Case Languages.Japanese
                Return "ja"
            Case Else
                Return ""
        End Select
    End Function

    Public Enum FollowStyles
        Text
        Bird
        Twitter
        LogoBig
        LogoMedium
        LogoSmall
    End Enum

    Public Enum FollowColors
        Blue
        Silver
        Black
    End Enum

    Public Shared Function GetFollowButtonImageUrl(ByVal followStyle As FollowStyles,
                                                   ByVal followColor As FollowColors) As String
        Dim fileName = ""

        Select Case followStyle
            Case FollowStyles.Text
                fileName = "follow_me-"
            Case FollowStyles.Bird
                fileName = "follow_bird-"
            Case FollowStyles.Twitter
                fileName = "twitter-"
            Case FollowStyles.LogoBig
                fileName = "t_logo-"
            Case FollowStyles.LogoMedium
                fileName = "t_small-"
            Case FollowStyles.LogoSmall
                fileName = "t_mini-"
        End Select
        Select Case followColor
            Case FollowColors.Blue
                fileName &= "a"
            Case FollowColors.Silver
                fileName &= "b"
            Case FollowColors.Black
                fileName &= "c"
        End Select

        Return fileName
    End Function

    Public Enum WidgetBehaviors
        [Default]
        All
    End Enum
End Functions 

@Helper TweetButton(
        Optional ByVal dataCount As DataCount = DataCount.Vertical,
        Optional ByVal tweetText As String = "",
        Optional ByVal url As String = "",
        Optional ByVal language As Languages = Languages.English,
        Optional ByVal username As String = "",
        Optional ByVal relatedUsername As String = "",
        Optional ByVal relatedUserDescription As String = "")

            Dim tweetTextAttribute = New HtmlString(If((Not tweetText.IsEmpty()), String.Format(" data-text=""{0}""", tweetText), ""))
            Dim urlAttribute = New HtmlString(If((Not url.IsEmpty()), String.Format(" data-url=""{0}""", url), ""))
            Dim languageAttribute = New HtmlString(If((Not GetLanguageCode(language).IsEmpty()), String.Format(" data-lang=""{0}""", GetLanguageCode(language)), ""))
            Dim usernameAttribute = New HtmlString(If((Not username.IsEmpty()), String.Format(" data-via=""{0}""", username), ""))
            Dim relatedAttribute = New HtmlString(If((Not relatedUsername.IsEmpty()), String.Format(" data-related=""{0}{1}""", relatedUsername, If((Not relatedUserDescription.IsEmpty()), ":" & relatedUserDescription, "")), ""))
@<a href="http://twitter.com/share" class="twitter-share-button"@tweetTextAttribute@urlAttribute@languageAttribute@usernameAttribute@relatedAttribute data-count="@dataCount.ToString().ToLower()">Tweet</a><script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
End Helper

@helper FollowButton(
        ByVal username As String,
        Optional ByVal followStyle As FollowStyles = FollowStyles.Text,
        Optional ByVal followColor As FollowColors = FollowColors.Blue)

@<a href="http://www.twitter.com/@username"><img src="http://twitter-badges.s3.amazonaws.com/@(GetFollowButtonImageUrl(followStyle, followColor)).png" alt="Follow @username on Twitter"/></a>
End Helper

@helper Profile(
        ByVal username As String,
         Optional ByVal width As Integer = 250, 
         Optional ByVal height As Integer = 300, 
         Optional ByVal backgroundShellColor As String = "#333333",
         Optional ByVal shellColor As String = "#ffffff", 
         Optional ByVal tweetsBackgroundColor As String = "#000000", 
         Optional ByVal tweetsColor As String = "#ffffff",
         Optional ByVal tweetsLinksColor As String = "#4aed05", 
         Optional ByVal numberOfTweets As Integer = 4, 
         Optional ByVal scrollBar As Boolean = False, 
         Optional ByVal [loop] As Boolean = False,
         Optional ByVal live As Boolean = False, 
         Optional ByVal hashTags As Boolean = True, 
         Optional ByVal timestamp As Boolean = True, 
         Optional ByVal avatars As Boolean = False, 
         Optional ByVal behavior As WidgetBehaviors = WidgetBehaviors.All,
         Optional ByVal interval As Integer = 6)

    @<script src="http://widgets.twimg.com/j/2/widget.js"></script>
@<script>
new TWTR.Widget({
  version: 2,
  type: 'profile',
  rpp: @(If(numberOfTweets < 1, 1, (If(numberOfTweets > 30, 30, numberOfTweets)))),
  interval: @(If(interval < 2, 2000, (If(interval > 20, 20000, (interval * 1000))))),
  width: @CType(New HtmlString(If(width <= 0, "'auto'", width.ToString())), HtmlString),
  height: @(If(height < 0, "0", height.ToString())),
  theme: {
    shell: {
      background: '@(If(backgroundShellColor.IsEmpty(), "#333333", backgroundShellColor))',
      color: '@(If(shellColor.IsEmpty(), "#ffffff", shellColor))'
    },
    tweets: {
      background: '@(If(tweetsBackgroundColor.IsEmpty(), "#000000", tweetsBackgroundColor))',
      color: '@(If(tweetsColor.IsEmpty(), "#ffffff", tweetsColor))',
      links: '@(If(tweetsLinksColor.IsEmpty(), "#4aed05", tweetsLinksColor))'
    }
  },
  features: {
    scrollbar: @scrollBar.ToString().ToLower(),
    loop: @loop.ToString().ToLower(),
    live: @live.ToString().ToLower(),
    hashtags: @hashTags.ToString().ToLower(),
    timestamp: @timestamp.ToString().ToLower(),
    avatars: @avatars.ToString().ToLower(),
    behavior: '@behavior.ToString().ToLower()'
  }
}).render().setUser('@username').start();
</script>
}

@* Advanced queries: http://search.twitter.com/operators *@
@Helper Search(
ByVal searchQuery As String, 
Optional ByVal width As Integer = 250,
 Optional ByVal height As Integer = 300, 
 Optional ByVal title As String = Nothing,
 Optional ByVal caption As String = Nothing, 
 Optional ByVal backgroundShellColor As String = "#8ec1da",
 Optional ByVal shellColor As String = "#ffffff",
 Optional ByVal tweetsBackgroundColor As String = "#ffffff",
 Optional ByVal tweetsColor As String = "#444444", 
 Optional ByVal tweetsLinksColor As String = "#1985b5", 
 Optional ByVal scrollBar As Boolean = False, 
 Optional ByVal [loop] As Boolean = True,
 Optional ByVal live As Boolean = True, 
 Optional ByVal hashTags As Boolean = True, 
 Optional ByVal timestamp As Boolean = True, 
 Optional ByVal avatars As Boolean = True,
 Optional ByVal topTweets As Boolean = True,
 Optional ByVal behavior As WidgetBehaviors = WidgetBehaviors.All, 
 Optional ByVal interval As Integer = 6)
@<script src="http://widgets.twimg.com/j/2/widget.js"></script>
@<script>
new TWTR.Widget({
  version: 2,
  type: 'search',
  search: '@searchQuery',
  interval: @(If(interval < 2, 2000, (If(interval > 20, 20000, (interval * 1000))))),
  title: '@title',
  subject: '@caption',
  width: @CType(New HtmlString(If(width <= 0, "'auto'", width.ToString())), HtmlString),
  height: @(If(height < 0, "0", height.ToString())),
  theme: {
    shell: {
      background: '@(If(backgroundShellColor.IsEmpty(), "#8ec1da", backgroundShellColor))',
      color: '@(If(shellColor.IsEmpty(), "#ffffff", shellColor))'
    },
    tweets: {
      background: '@(If(tweetsBackgroundColor.IsEmpty(), "#ffffff", tweetsBackgroundColor))',
      color: '@(If(tweetsColor.IsEmpty(), "#444444", tweetsColor))',
      links: '@(If(tweetsLinksColor.IsEmpty(), "#1985b5", tweetsLinksColor))'
    }
  },
  features: {
    scrollbar: @scrollBar.ToString().ToLower(),
    loop: @loop.ToString().ToLower(),
    live: @live.ToString().ToLower(),
    hashtags: @hashTags.ToString().ToLower(),
    timestamp: @timestamp.ToString().ToLower(),
    avatars: @avatars.ToString().ToLower(),
    toptweets: @topTweets.ToString().ToLower(),
    behavior: '@behavior.ToString().ToLower()'
  }
}).render().start();
</script>
End Helper

@Helper Faves(
ByVal username As String,
 Optional ByVal width As Integer = 250, 
 Optional ByVal height As Integer = 300,
 Optional ByVal title As String = Nothing,
 Optional ByVal caption As String = Nothing, 
 Optional ByVal backgroundShellColor As String = "#43c43f", 
 Optional ByVal shellColor As String = "#ffffff", 
 Optional ByVal tweetsBackgroundColor As String = "#ffffff", 
 Optional ByVal tweetsColor As String = "#444444", 
 Optional ByVal tweetsLinksColor As String = "#43c43f", 
 Optional ByVal numberOfTweets As Integer = 10, 
 Optional ByVal scrollBar As Boolean = True,
 Optional ByVal [loop] As Boolean = False, 
 Optional ByVal live As Boolean = True, 
 Optional ByVal hashTags As Boolean = True, 
 Optional ByVal timestamp As Boolean = True,
 Optional ByVal avatars As Boolean = True,
 Optional ByVal topTweets As Boolean = True, 
 Optional ByVal behavior As WidgetBehaviors = WidgetBehaviors.All, 
 Optional ByVal interval As Integer = 6)
@<script src="http://widgets.twimg.com/j/2/widget.js"></script>
@<script>
new TWTR.Widget({
  version: 2,
  type: 'faves',
  rpp: @(If(numberOfTweets < 1, 1, (If(numberOfTweets > 20, 20, numberOfTweets)))),
  interval: @(If(interval < 2, 2000, (If(interval > 20, 20000, (interval * 1000))))),
  title: '@title',
  subject: '@caption',
  width: @CType(New HtmlString(If(width <= 0, "'auto'", width.ToString())), HtmlString),
  height: @(If(height < 0, "0", height.ToString())),
  theme: {
    shell: {
      background: '@(If(backgroundShellColor.IsEmpty(), "#43c43f", backgroundShellColor))',
      color: '@(If(shellColor.IsEmpty(), "#ffffff", shellColor))'
    },
    tweets: {
      background: '@(If(tweetsBackgroundColor.IsEmpty(), "#ffffff", tweetsBackgroundColor))',
      color: '@(If(tweetsColor.IsEmpty(), "#444444", tweetsColor))',
      links: '@(If(tweetsLinksColor.IsEmpty(), "#43c43f", tweetsLinksColor))'
    }
  },
  features: {
    scrollbar: @scrollBar.ToString().ToLower(),
    loop: @loop.ToString().ToLower(),
    live: @live.ToString().ToLower(),
    hashtags: @hashTags.ToString().ToLower(),
    timestamp: @timestamp.ToString().ToLower(),
    avatars: @avatars.ToString().ToLower(),
    behavior: '@behavior.ToString().ToLower()'
  }
}).render().setUser('@username').start();
</script>
End Helper

@Helper List(
ByVal username As String,
ByVal list As String, 
Optional ByVal width As Integer = 250, 
Optional ByVal height As Integer = 300,
 Optional ByVal title As String = Nothing, 
 Optional ByVal caption As String = Nothing, 
 Optional ByVal backgroundShellColor As String = "#ff96e7",
 Optional ByVal shellColor As String = "#ffffff",
 Optional ByVal tweetsBackgroundColor As String = "#ffffff", 
 Optional ByVal tweetsColor As String = "#444444",
 Optional ByVal tweetsLinksColor As String = "#b740c2", 
 Optional ByVal numberOfTweets As Integer = 30, 
 Optional ByVal scrollBar As Boolean = True, 
 Optional ByVal [loop] As Boolean = False,
 Optional ByVal live As Boolean = True, 
 Optional ByVal hashTags As Boolean = True,
 Optional ByVal timestamp As Boolean = True, 
 Optional ByVal avatars As Boolean = True, 
 Optional ByVal topTweets As Boolean = True, 
 Optional ByVal behavior As WidgetBehaviors = WidgetBehaviors.All,
 Optional ByVal interval As Integer = 6)
@<script src="http://widgets.twimg.com/j/2/widget.js"></script>
@<script>
new TWTR.Widget({
  version: 2,
  type: 'list',
  rpp: @(If(numberOfTweets < 1, 1, (If(numberOfTweets > 100, 100, numberOfTweets)))),
  interval: @(If(interval < 2, 2000, (If(interval > 20, 20000, (interval * 1000))))),
  title: '@title',
  subject: '@caption',
  width: @CType(New HtmlString(If(width <= 0, "'auto'", width.ToString())), HtmlString),
  height: @(If(height < 0, "0", height.ToString())),
  theme: {
    shell: {
      background: '@(If(backgroundShellColor.IsEmpty(), "#ff96e7", backgroundShellColor))',
      color: '@(If(shellColor.IsEmpty(), "#ffffff", shellColor))'
    },
    tweets: {
      background: '@(If(tweetsBackgroundColor.IsEmpty(), "#ffffff", tweetsBackgroundColor))',
      color: '@(If(tweetsColor.IsEmpty(), "#444444", tweetsColor))',
      links: '@(If(tweetsLinksColor.IsEmpty(), "#b740c2", tweetsLinksColor))'
    }
  },
  features: {
    scrollbar: @scrollBar.ToString().ToLower(),
    loop: @loop.ToString().ToLower(),
    live: @live.ToString().ToLower(),
    hashtags: @hashTags.ToString().ToLower(),
    timestamp: @timestamp.ToString().ToLower(),
    avatars: @avatars.ToString().ToLower(),
    behavior: '@behavior.ToString().ToLower()'
  }
}).render().setList('@username', '@list').start();
</script>
End Helper
    