﻿@Code
    WebSecurity.RequireAuthenticatedUser()

	Dim photoId = UrlData(0).AsInt()

	Dim db = Database.Open("PhotoGallery")

	Dim photo = db.QuerySingle("SELECT * FROM Photos WHERE Id = @0", photoId)
	If photo Is Nothing Then
		Response.SetStatus(HttpStatusCode.NotFound)
		Return
	End If

	Page.Title = "Photo Tags - " & photo.FileTitle

	If IsPost Then
		Dim newTags = Request("newTags")
		' prepare tags for processing
		Dim tagNames = newTags.Split(";"c)

		'Clear Tags associated with this image
		db.Execute("DELETE FROM Photos_Tags WHERE Photos_Id = @0", photoId)
        For Each tagName In tagNames
            ' get the tag ID for each tag, else create if doesn't exist
            Dim trimmed = tagName.Trim()
            Dim exists = db.QueryValue("SELECT COUNT(*) FROM Tags WHERE TagName = @0", trimmed) > 0
            If Not exists Then db.Execute("INSERT INTO Tags (TagName) VALUES (@0)", trimmed)
            'Associate image and tag
            db.Execute("INSERT INTO Photos_Tags (Photos_Id, Tags_TagName) VALUES (@0, @1)", photoId, trimmed)
        Next tagName
		Response.Redirect(Href("View", photo.Id))
	End If

	' get a list of all the tags for this photo, sorted
	Dim tags = db.Query("SELECT TagName FROM Tags, Photos_Tags WHERE Tags_TagName = TagName AND Photos_Id = @0 ORDER BY TagName", photoId)

	Dim tagsList = New List(Of String)
	For Each tag In tags
		tagsList.Add(tag.TagName)
	Next tag
	Dim tagStringToDisplay = String.Join("; ", tagsList.ToArray())
End Code

<div class="sidebar">
    <h1>Edit Photo's Tags</h1>
    <h2>@photo.FileTitle</h2>
    <form method="post" action="">
        <fieldset class="no-legend">
            <legend>Edit Tags</legend>
            <ol>
                <li>
                    <label for="newTags">Enter tags, semicolon-delimited:</label>
                    <textarea id="newTags" name="newTags" title="Enter tags seperated by a semicolon" rows="4" cols="50" placeholder="Enter tags seperated by a semicolon">@tagStringToDisplay</textarea>
                </li>
            </ol>
            <p class="form-actions">
                <input type="submit" value="Save Changes" title="Save changes" />
                <a href="@Href("~/Photo/View", photoId)" title="Do not save changes">Cancel</a>
            </p>
        </fieldset>
    </form>
</div>
<div class="main">
    <img alt="@Html.AttributeEncode(photo.FileTitle)" src="@Href("~/Photo/Thumbnail", photo.Id, New With {.size = "large"})" />
</div>