﻿@Code
    Dim photoId = UrlData(0).AsInt()

	Dim db = Database.Open("PhotoGallery")

	Dim photo = db.QuerySingle("SELECT * FROM Photos WHERE Id = @0", photoId)
	If photo Is Nothing Then
		Response.SetStatus(HttpStatusCode.NotFound)
		Return
	End If

	Page.Title = "Photo - " & photo.FileTitle

	Dim description As String = photo.description

	If IsPost Then
		Dim newComment = Request("newComment").Trim()
		If newComment.IsEmpty() Then Response.Redirect(Href("View", photoId))

        db.Execute("INSERT INTO Comments (PhotoId, CommentDate, UserId, CommentText) VALUES (@0, @1, @2, @3)",
                   photoId,
                   Date.Now,
                   WebSecurity.CurrentUserId,
                   newComment)

		Response.Redirect(Href("View",photoId))
		Return
	End If

	' Found a match - so show its info
	Dim user = db.QuerySingle("SELECT * FROM UserProfiles WHERE UserId = @0", photo.UserId)
	Dim gallery = db.QuerySingle("SELECT * FROM Galleries WHERE Id = @0", photo.GalleryId)
	Dim comments = db.Query("SELECT * FROM Comments INNER JOIN UserProfiles " & 
    "ON Comments.UserId = UserProfiles.UserId WHERE PhotoId = @0 ORDER BY Comments.CommentDate", photo.Id)
	Dim tagList = db.Query("SELECT Tags_TagName FROM Photos_Tags WHERE Photos_Id = @0 ORDER BY Tags_TagName", photo.Id)
End Code

<div class="sidebar">
    <h1>@photo.FileTitle</h1>
    @If user.UserId = WebSecurity.CurrentUserId Then
        @<p>
            As the author, you can <a href="@Href("~/Photo/Edit", photoId)">edit</a>
            or <a href="@Href("~/Photo/Remove", photoId)">remove</a> this photo.
        </p>
    End If
    <dl>
        <dt class="description">Description</dt>
        <dd class="description">
            @If Not description.IsEmpty() Then 
                @<text>@photo.Description</text>
            Else
                @<text>The uploader did not provide a description for this photo.</text>
            End If
        </dd>
        <dt class="uploaded-by">Uploaded by</dt>
        <dd class="uploaded-by"><a href="@Href("~/User/View", user.UserId)">@user.DisplayName</a></dd>
        <dt class="upload-date">Upload date</dt>
        <dd class="upload-date">@photo.UploadDate</dd>
        <dt class="part-of-gallery">Gallery</dt>
        <dd><a href="@Href("~/Gallery/View", gallery.Id)" title="View @gallery.Name gallery">@gallery.Name</a></dd>
        <dt class="tags">Tags</dt>
        <dd class="tags">
            <ul class="tags">
            @If tagList.Count = 0 Then
                @<li>This photo has no tags.</li>
            Else
                 For Each t In tagList
                    @<li class="tag"><a href="@Href("~/Tag/View", t.Tags_TagName)">@t.Tags_TagName</a></li>
                Next t
            End If
            </ul>
            @If WebSecurity.IsAuthenticated Then
                @<a href="@Href("~/Photo/EditTags", photoId)">edit tags</a>
            End If
        </dd>
    </dl>

    <p>
        <a class="download" href="@Href("~/Photo/Full", photoId)" title="Download: @(photo.FileTitle + photo.FileExtension)">Download full photo</a> (@(photo.FileSize \ 1024) KB)
    </p>
</div>
<div class="main">
    <img class="large-photo" alt="@Html.AttributeEncode(photo.FileTitle)" src="@Href("~/Photo/Thumbnail", photo.Id, New With {.size = "large"})" />

    @Select Case CInt(comments.Count)
        Case 0
           @<h2>Nobody has commented on this photo</h2>
            
        case 1
            @<h2>This photo has generated one comment.</h2>
           
        Case Else
            @<h2>This photo has generated @comments.Count comments.</h2>
            
        End Select

    <ol class="comments">
        @For Each comment In comments
            @<li>
                <h3 class="comment-header">
                    <a href="@Href("~/User/View", comment.UserId)" title="View @(comment.DisplayName)'s profile">@comment.DisplayName</a> commented at @comment.CommentDate:
                </h3>
                <p class="comment-body">@comment.CommentText</p>
            </li>
        Next comment
    </ol>

    @If WebSecurity.IsAuthenticated Then
        @<form method="post" action="">
            <fieldset id="addComment">
                <legend>Post new comment</legend>
                <ol>
                    <li>
                        <label for="newComment">Comment</label>
                        <textarea id="newComment" name="newComment" title="Your comment" rows="6" cols="70"></textarea>
                    </li>
                </ol>
                <p class="form-actions">
                    <input type="submit" title="Add comment" value="Add comment" />
                </p>
            </fieldset>
        </form>
    Else
        @<p>
            Only registered user may leave comments. Please <a href="@Href("~/Account/Login")">login</a> 
            or <a href="@Href("~/Account/Register")">create an account</a> to leave a comment.
        </p>
    End If
</div>